function toAbsoluteUrl(url)
{
    if(url.search(/^\/\//) != -1) return window.location.protocol + url;
    if(url.search(/:\/\//) != -1) return url;
    if(url.search(/^\//)   != -1) return window.location.origin + url;

    return window.location.href.match(/(.*\/)/)[0] + url;
}

function getSources(mediaTag)
{
    var sources = mediaTag.getElementsByTagName("source");
    var sourceUrls = [];

    if(sources.length == 0)
    {
        return null;
    }

    for(var i = 0; i < sources.length; ++i)
    {
        if(sources[i].hasAttribute("src"))
        {
            sourceUrls.push(toAbsoluteUrl(sources[i].getAttribute("src")));
        }
    }

    return sourceUrls;
}

function processMediaTag(mediaTag, srcCallBack, sourcesCallBack)
{
    if(!mediaTag)
    {
        return;
    }

    if(mediaTag.hasAttribute("src"))
    {
        srcCallBack(toAbsoluteUrl(mediaTag.getAttribute("src")));
        return;
    }

    var sourceUrls = getSources(mediaTag);

    if(sourceUrls)
    {
        sourcesCallBack(JSON.stringify(sourceUrls));
        return;
    }
}

function getFirstPlayingMediaTag(mediaTags)
{
    for(var i = 0; i < mediaTags.length; ++i)
    {
        if(!mediaTags[i].paused && !mediaTags[i].ended)
        {
            return mediaTags[i];
        }
    }

    return null;
}

function onVideoSrcItercept(url)     { window.VideoCallback.onVideoSrcItercept(window.location.href, url);     }
function onVideoSourcesItercept(url) { window.VideoCallback.onVideoSourcesItercept(window.location.href, url); }

function onAudioSrcItercept(url)     { window.VideoCallback.onAudioSrcItercept(window.location.href, url);     }
function onAudioSourcesItercept(url) { window.VideoCallback.onAudioSourcesItercept(window.location.href, url); }

function processVideoEvent(event)
{
    if(event.target.nodeName.toUpperCase() === "VIDEO")
    {
        processMediaTag(event.target, onVideoSrcItercept, onVideoSourcesItercept);
    }
    else if(event.target.contentDocument && event.target.contentDocument.getElementsByTagName('VIDEO').length > 0)
    {
        var videoTags = event.target.contentDocument.getElementsByTagName('VIDEO');
        processMediaTag(getFirstPlayingMediaTag(videoTags), onVideoSrcItercept, onVideoSourcesItercept);
    }
}

function processAudioEvent(event)
{
    if(event.target.nodeName.toUpperCase() === "AUDIO")
    {
        processMediaTag(event.target, onAudioSrcItercept, onAudioSourcesItercept);
    }
    else if(event.target.contentDocument && event.target.contentDocument.getElementsByTagName('AUDIO').length > 0)
    {
        var audioTags = event.target.contentDocument.getElementsByTagName('AUDIO');
        processMediaTag(getFirstPlayingMediaTag(audioTags), onAudioSrcItercept, onAudioSourcesItercept);
    }
}

document.addEventListener("play", processVideoEvent, true);
document.addEventListener("play", processAudioEvent, true);
